@@ -30,3 +30,10 @@ class DBConnect():
         except Exception as err:
             logging.warning('MongoDB(组件)出现未知错误: {0}'.format(err))
             return False
+
+    def does_it_exist(self, docu: dict) -> bool:
+        count = self.mongo_collection.count_documents(docu)
+        if count != 0:
+            return True
+        else:
+            return False
